@@ -1,23 +1,23 @@
 
-from django.apps import apps
+from django.conf import settings
 from django.db import connections
 from django.template.loader import render_to_string
 
-from turbosms import config
-
 
 def get_default_sms_recipients():
 
-    if apps.is_installed('site_config'):
-        from site_config import config as _config
-        return getattr(config, 'SMS_RECIPIENTS', _config.SMS_RECIPIENTS)
+    try:
+        from site_config import config
+        return config.SMS_RECIPIENTS
+    except (ImportError, AttributeError):
+        pass
 
-    return config.SMS_RECIPIENTS
+    return getattr(settings, 'SMS_RECIPIENTS', [])
 
 
 def send_sms(message, recipients=None):
 
-    if not config.IS_SMS_ENABLED:
+    if not getattr(settings, 'IS_SMS_ENABLED', False):
         return
 
     if recipients is None:
@@ -25,14 +25,14 @@ def send_sms(message, recipients=None):
 
     query = (
         'INSERT INTO {} (number, message, sign) VALUES (%s, %s, %s)'
-    ).format(config.SMS_USERNAME)
+    ).format(settings.SMS_USERNAME)
 
     with connections['turbosms'].cursor() as cursor:
         for number in recipients:
             cursor.execute(query, [
                 number,
                 message,
-                config.SMS_SIGNATURE])
+                getattr(settings, 'SMS_SIGNATURE', 'Msg')])
 
 
 def send_sms_from_template(template_name, context=None, recipients=None):
